#ifndef STATISTICSDISPLAY_H_
#define STATISTICSDISPLAY_H_

#include <iostream>

#include "DisplayElement.h"
#include "Observer.h"
#include "Subject.h"
#include "WeatherData.h"

class StatisticsDisplay : public Observer, DisplayElement
{
private:
    float maxTemp;
    float minTemp;
    float tempSum;
    int numReadings;

    Subject *subject;

public:
    StatisticsDisplay(Subject *sub)
        : maxTemp(0.0f), minTemp(200), tempSum(0.0f),
          numReadings(0), subject(sub)
    {
        subject->register_observer(this);
    }

    virtual ~StatisticsDisplay() {}

    void update(float temp, float hum, float pres)
    {
        tempSum += temp;
        numReadings++;

        if (temp > maxTemp) maxTemp = temp;
        if (temp < minTemp) minTemp = temp;

        display();
    }

    void display()
    {
        cout << "        Statistics: Avg/Max/Min temperature = "
             << tempSum/numReadings
             << "/" << maxTemp << "/" << minTemp << endl;
    }
};

#endif /* STATISTICSDISPLAY_H_ */
